From 480a877bb8d3570e86a9f5f7befb921d603e59aa Mon Sep 17 00:00:00 2001
From: Haidong Yu <yuhaidong@uniontech.com>
Date: Tue, 23 Jun 2020 18:33:43 +0800
Subject: [PATCH 1/2] user32/tests: Add test of ShowWindow with SW_SHOWNOACTIVATE
 option.

Signed-off-by: Haidong Yu <yuhaidong@uniontech.com>
---
 dlls/user32/tests/msg.c | 31 +++++++++++++++++++++++++++++++
 1 file changed, 31 insertions(+)

diff --git a/dlls/user32/tests/msg.c b/dlls/user32/tests/msg.c
index 935e4379e9..3768e608a2 100644
--- a/dlls/user32/tests/msg.c
+++ b/dlls/user32/tests/msg.c
@@ -17812,6 +17812,36 @@ done:
     DestroyWindow(hwnd);
 }
 
+static void test_show_no_active(void)
+{
+    HWND hwnd, popup;
+
+    hwnd = CreateWindowExA(WS_EX_LEFT | WS_EX_LTRREADING | WS_EX_RIGHTSCROLLBAR | WS_EX_WINDOWEDGE, "TestWindowClass", "MainWnd",
+                           WS_CLIPSIBLINGS | WS_CLIPCHILDREN | WS_SYSMENU | WS_VISIBLE | WS_OVERLAPPED | WS_MINIMIZEBOX | WS_MAXIMIZEBOX,
+                           100, 100, 200, 200, 0, 0, 0, NULL);
+
+    popup = CreateWindowExA(WS_EX_LEFT | WS_EX_LTRREADING | WS_EX_RIGHTSCROLLBAR | WS_EX_TOOLWINDOW | WS_EX_LAYERED | WS_EX_NOACTIVATE, "TestWindowClass", "layeredWnd",
+                            WS_CLIPSIBLINGS | WS_CLIPCHILDREN | WS_VISIBLE | WS_POPUP,
+                            110, 110, 200, 200, hwnd, 0, 0, NULL);
+
+    SetLayeredWindowAttributes(popup, 0,150, LWA_ALPHA);
+
+    ok(hwnd != 0, "Failed to create overlapped window\n");
+    ok(popup != 0, "Failed to create popup window\n");
+
+    ShowWindow(hwnd, SW_SHOWNORMAL);
+    flush_events();
+
+    SendMessageA(hwnd, WM_SYSCOMMAND, SC_MINIMIZE, NULL);
+    flush_events();
+
+    ShowWindow(hwnd, SW_SHOWNOACTIVATE);
+    flush_events();
+    ok(GetWindowLongA(popup, GWL_STYLE)&WS_VISIBLE, "The window should be visible\n");
+
+    DestroyWindow(hwnd);
+}
+
 static void test_invalid_window(void)
 {
     MSG msg;
@@ -17955,6 +17985,7 @@ START_TEST(msg)
     test_restore_messages();
     test_invalid_window();
 
+    test_ShowOwnedPopups();
     if (!pTrackMouseEvent)
         win_skip("TrackMouseEvent is not available\n");
     else
-- 
2.20.1

